summaryrefslogtreecommitdiff
path: root/nuttx/include/stdbool.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 23:32:23 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2009-12-14 23:32:23 +0000
commitd7d4a0d765d12cc152c62a37b490702c39d76447 (patch)
treed3969c50e49cd742124e05349431556344a93f54 /nuttx/include/stdbool.h
parent313eb5bb780f9e9baa353651996b51ce33a85fca (diff)
downloadpx4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.tar.gz
px4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.tar.bz2
px4-nuttx-d7d4a0d765d12cc152c62a37b490702c39d76447.zip
Switching to C99 stdint.h types
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@2340 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/include/stdbool.h')
-rwxr-xr-xnuttx/include/stdbool.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/nuttx/include/stdbool.h b/nuttx/include/stdbool.h
index d290ca18a..fad1c3080 100755
--- a/nuttx/include/stdbool.h
+++ b/nuttx/include/stdbool.h
@@ -43,6 +43,8 @@
#include <nuttx/config.h>
#include <nuttx/compiler.h>
+#include <stdint.h>
+
/****************************************************************************
* Pre-processor Definitions
****************************************************************************/
@@ -62,10 +64,10 @@
****************************************************************************/
/* A byte is the smallest address memory element (at least in architectures
* that do not support bit banding. We select ubyte versus the more standard
* int as the underlying type to minimize the RAM footprint of the executable.
*/
-typedef ubyte _Bool;
+typedef uint8_t _Bool;
#endif /* __INCLUDE_STDBOOL_H */
@@ -62,10 +64,10 @@
****************************************************************************/
/* A byte is the smallest address memory element (at least in architectures
- * that do not support bit banding. We select ubyte versus the more standard
+ * that do not support bit banding. We select uint8_t versus the more standard
* int as the underlying type to minimize the RAM footprint of the executable.
*/